#ifndef TAIRO_H
#define TAIRO_H
/*
   	Tairo v0.61
    Copyright (C) 2004 Jonas Gehring
        
    Tairo is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    Tairo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Tairo; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

// Header File
// Created 30.10.04; 12:27:09

#include <asmtypes.h>					// Common type definitions known to ASM programmers
#include <compat.h>						// Various calc-dependent and AMS-dependent pseudo-constants


/*____________________Constants & Macros_____________________*/
#define CALCY ((LCD_HEIGHT-100)/2)
#define CALCX ((LCD_WIDTH-160)/2)
#define HEIGHT 8
#define LOGOHEIGHT 46
#define GRAYPL GrayGetPlane(DARK_PLANE),GrayGetPlane(LIGHT_PLANE)
#define GetSpr(pl, nr) &(sprts[(nr*HEIGHT*2)+(pl*HEIGHT)])
#define GetLogo(pl, nr) &(logo[(nr*LOGOHEIGHT*2)+(pl*LOGOHEIGHT)])
#define MAX_LEVELS 45

enum levels {UNVALID = -1, EMPTY, FILLED};
enum extrakeys {KEY_RIGHT2ND = 4436, KEY_LEFT2ND = 4433, KEY_UNDO = 257};

// This defines all the values we can set in the startup menu 
typedef struct {
	short mode;
	short diff;
	short level;
}	START_OPTIONS;

// A structure for saving/loading
typedef struct {
	short wininfo[MAX_LEVELS];
} SAVE_LOAD;



/*_________________________Globals___________________________*/
BOOL timeout;
BOOL tmr;
short pieces_left;
SAVE_LOAD savload;
short time;


/*________________________Proto-Types________________________*/
// tairo.c
void ExitTairo(void);												// Exits the game
void _main(void);													// Programm entry point

// game.c
void GamePlay(START_OPTIONS options);								// "Main routine" of the game
BOOL SelectCoin(void);												// Selects a coin
CALLBACK void CursorBlink(void);									// Lets the cursor blink
CALLBACK void StopTimer(void);										// Stops the time for 'TIME'-mode
void MoveCur(short dir);											// Moves the cursor
void MoveCoin(void);												// Jumping process
short SelectDir(void);												// Select direction for jump
BOOL CheckGameOver(void);											// Checks if the player is still able to move
void TimeOut(void);													// Time's Out!
void Undo(void);													// Undo-Function (1-Level)
unsigned short Key_Wait(void);										// Waits for a key and returns the value

// gfx.c
START_OPTIONS DoIntro(BOOL mode);									// Show startup-options
void DrawField(short level);										// Draws the playing field
void DrawSel(short x, short y, short olddir,						// Draw "cursor" to select a direction to jump
						 short dir);											
BOOL ReallyQuit(void);												// Makes sure that the user hasn't pressed ESC without wanting to quit
void FillWithBalls(void);											// Fills the empty space on calcs with 240*128-screen with sprites
void AnimateJump(short x0, short y0, 								// Animates a jump
								 short dir);

// util.c
void ClearScr(void);												// Clears the screen. If we have no TI89, the unused space is filled with black
void DrawBox(void);													// Draws a box for messages
void Save(SAVE_LOAD *wininfo);										// Routine for saving														
BOOL Load(void);													// Routine for loading

#endif